==> firefox-68.12.0esr.source.tar.xz: firefox-68.12.0/dom/workers/RegisterBindings.cpp <==
/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim: set ts=8 sts=2 et sw=2 tw=80: */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this file,
 * You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "WorkerPrivate.h"
#include "ChromeWorkerScope.h"
#include "RuntimeService.h"

#include "jsapi.h"
#include "mozilla/dom/RegisterWorkerBindings.h"
#include "mozilla/dom/RegisterWorkerDebuggerBindings.h"
#include "mozilla/OSFileConstants.h"

using namespace mozilla::dom;

bool WorkerPrivate::RegisterBindings(JSContext* aCx,
                                     JS::Handle<JSObject*> aGlobal) {
  // Init Web IDL bindings
  if (!RegisterWorkerBindings(aCx, aGlobal)) {
    return false;
  }

  if (IsChromeWorker()) {
    if (!DefineChromeWorkerFunctions(aCx, aGlobal)) {
      return false;
    }

    RefPtr<OSFileConstantsService> service =
        OSFileConstantsService::GetOrCreate();
    if (!service->DefineOSFileConstants(aCx, aGlobal)) {
      return false;
    }
  }

  if (!JS_DefineProfilingFunctions(aCx, aGlobal)) {
    return false;
  }

  return true;
}

bool WorkerPrivate::RegisterDebuggerBindings(JSContext* aCx,
                                             JS::Handle<JSObject*> aGlobal) {
  // Init Web IDL bindings
  if (!RegisterWorkerDebuggerBindings(aCx, aGlobal)) {
    return false;
  }

  if (!ChromeUtils_Binding::GetConstructorObject(aCx)) {
    return false;
  }

  if (!JS_DefineDebuggerObject(aCx, aGlobal)) {
    return false;
  }

  return true;
}

==> firefox-91.5.1esr.source.tar.xz: firefox-91.5.1/dom/workers/RegisterBindings.cpp <==
/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim: set ts=8 sts=2 et sw=2 tw=80: */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this file,
 * You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "WorkerPrivate.h"
#include "ChromeWorkerScope.h"

#include "jsapi.h"
#include "mozilla/dom/DebuggerNotificationObserverBinding.h"
#include "mozilla/dom/RegisterWorkerBindings.h"
#include "mozilla/dom/RegisterWorkerDebuggerBindings.h"
#include "mozilla/OSFileConstants.h"

using namespace mozilla::dom;

bool WorkerPrivate::RegisterBindings(JSContext* aCx,
                                     JS::Handle<JSObject*> aGlobal) {
  // Init Web IDL bindings
  if (!RegisterWorkerBindings(aCx, aGlobal)) {
    return false;
  }

  if (IsChromeWorker()) {
    if (!DefineChromeWorkerFunctions(aCx, aGlobal)) {
      return false;
    }

    RefPtr<OSFileConstantsService> service =
        OSFileConstantsService::GetOrCreate();
    if (!service->DefineOSFileConstants(aCx, aGlobal)) {
      return false;
    }
  }

  return true;
}

bool WorkerPrivate::RegisterDebuggerBindings(JSContext* aCx,
                                             JS::Handle<JSObject*> aGlobal) {
  // Init Web IDL bindings
  if (!RegisterWorkerDebuggerBindings(aCx, aGlobal)) {
    return false;
  }

  if (!ChromeUtils_Binding::GetConstructorObject(aCx)) {
    return false;
  }

  if (!DebuggerNotificationObserver_Binding::GetConstructorObject(aCx)) {
    return false;
  }

  if (!JS_DefineDebuggerObject(aCx, aGlobal)) {
    return false;
  }

  return true;
}
